@@ -74,6 +74,9 @@ class DeskbarPreferences:
         self.more_button.set_sensitive(False)
         self.more_button.connect("clicked", self.on_more_button_clicked)
         self.more_button_callback = None
+        self.reload_button = self.glade.get_widget("reload")
+        self.reload_button.connect("clicked", self.on_reload_button_clicked)
+        self.reload_button.set_tooltip_text(_("Reload all extensions"))
 
         # Info are at the bottom
         self.info_area = self.glade.get_widget("info_area")
@@ -103,6 +106,9 @@ class DeskbarPreferences:
         self.use_selection_box.connect('toggled', self.on_use_selection_toggled)
         #self.use_selection_id = deskbar.GCONF_CLIENT.notify_add(applet.prefs.GCONF_USE_SELECTION, lambda x, y, z, a: self.on_config_use_selection(z.value))
 
+        self.sticktopanel_checkbox = self.glade.get_widget("sticktopanel_checkbox")
+        self.sticktopanel_checkbox.connect("toggled", self.on_ui_changed)
+       
     def __setup_drag_and_drop(self):
         big_box = self.glade.get_widget("big_box")
         self.TARGET_URI_LIST, self.TARGET_NS_URL = range(2)
@@ -134,12 +140,15 @@ class DeskbarPreferences:
                 notebook.prev_page()
 
     def __is_nsm_available(self):
-        bus = dbus.SessionBus()
-        proxy = bus.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus')
-        _dbus = dbus.Interface(proxy, 'org.freedesktop.DBus')
-        _dbus.ReloadConfig()
-        bus_names = _dbus.ListActivatableNames()
-        return (NewStuffUpdater.NEW_STUFF_SERVICE in bus_names)
+        try:
+            bus = dbus.SessionBus()
+            proxy = bus.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus')
+            _dbus = dbus.Interface(proxy, 'org.freedesktop.DBus')
+            _dbus.ReloadConfig()
+            bus_names = _dbus.ListActivatableNames()
+            return (NewStuffUpdater.NEW_STUFF_SERVICE in bus_names)
+        except dbus.exceptions.DBusException:
+            return False
 
     def __enable_newstuffmanager(self, status):
         if status:
@@ -187,7 +196,7 @@ class DeskbarPreferences:
         self.dialog.connect("response", self.on_dialog_response)
     
     def on_dialog_response(self, dialog, response):
-        self.update_gconf()    
+        self._model.update_gconf()
         self.dialog.destroy()
         if self.newstuff != None:
             self.newstuff.close()
@@ -199,6 +208,8 @@ class DeskbarPreferences:
             self.keyboard_shortcut_entry.set_accelerator_name("<Alt>F3")
         
         self.use_selection_box.set_active(self.use_selection)
+         
+        self.sticktopanel_checkbox.set_active( self._model.get_ui_name() == deskbar.BUTTON_UI_NAME)
    
     def on_hide_after_action_toggled(self, toggle):
         self._model.set_hide_after_action(toggle.get_active())
@@ -216,10 +227,16 @@ class DeskbarPreferences:
 
     def on_use_selection_toggled(self, toggle):
         self._model.set_use_selection(toggle.get_active())
+
+    def on_use_newstyleui_toggled(self, toggle):
+        self._model.set_use_newstyleui(toggle.get_active())
         
     def on_more_button_clicked(self, button):
         if self.more_button_callback != None:
             self.more_button_callback(self.dialog)
+
+    def on_reload_button_clicked(self, button):
+        self._model.reload_all_modules()
     
     def on_module_selected(self, selection):
         module_context = self.moduleview.get_selected_module()
@@ -304,7 +321,7 @@ class DeskbarPreferences:
             self._model.stop_module (module, False)
         else:
             self._model.initialize_module (module, False)
-        self.update_gconf()
+        self._model.update_gconf()
        
     def on_newstuff_error(self, newstuff, error):
           """
@@ -416,7 +433,8 @@ class DeskbarPreferences:
         self.set_buttons(self.moduleview.get_selection())
         self.moduleview.grab_focus()
         
-    def update_gconf(self):
-         # Update the gconf enabled modules settings
-        enabled_modules = [mod.__class__.__name__ for mod in self.module_list if mod.is_enabled()]
-        self._model.set_enabled_modules(enabled_modules)
+    def on_ui_changed(self, check):
+        if self.sticktopanel_checkbox.get_active():
+            self._model.set_ui_name(deskbar.BUTTON_UI_NAME)
+        else:
+            self._model.set_ui_name(deskbar.WINDOW_UI_NAME)
